@@ -12,7 +12,7 @@ my $api_key = shift(@ARGV);
 
 my $cm = Games::CroqueMonster->new( agency_name => $agency, api_key => $api_key);
 
-# print "Monsters:\n",Dumper( $cm->monsters() ),"\n";
-# print "Portals:\n",Dumper( $cm->portals() ),"\n";
-# print "Contracts:\n",Dumper( $cm->contracts() ),"\n";
+print "Monsters:\n",Dumper( $cm->monsters() ),"\n";
+print "Portals:\n",Dumper( $cm->portals() ),"\n";
+print "Contracts:\n",Dumper( $cm->contracts() ),"\n";
 print "Inventory:\n",Dumper( $cm->inventory() ),"\n";
